==> ntopng-5.6.tar.gz: ntopng-5.6/src/host_alerts/FlowHitsAlert.cpp <==
/*
 *
 * (C) 2013-23 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include "host_alerts_includes.h"

/* ***************************************************** */

FlowHitsAlert::FlowHitsAlert(HostCheck *c, Host *h, risk_percentage cli_pctg,
			     u_int16_t _hits, u_int64_t _threshold, bool _is_attacker)
  : HostAlert(c, h, cli_pctg) {
  hits = _hits;
  hits_threshold = _threshold;
  is_attacker = _is_attacker;
};

/* ***************************************************** */

ndpi_serializer* FlowHitsAlert::getAlertJSON(ndpi_serializer* serializer) {
  if(serializer == NULL)
    return NULL;

  ndpi_serialize_string_boolean(serializer, "is_attacker", is_attacker);
  ndpi_serialize_string_uint64(serializer, "value", hits);
  ndpi_serialize_string_uint64(serializer, "threshold", hits_threshold);
  
  return serializer;
}

/* ***************************************************** */

==> ntopng-6.0.tar.gz: ntopng-6.0/src/host_alerts/FlowHitsAlert.cpp <==
/*
 *
 * (C) 2013-23 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#include "host_alerts_includes.h"

/* ***************************************************** */

FlowHitsAlert::FlowHitsAlert(HostCheck* c, Host* h, risk_percentage cli_pctg,
                             u_int16_t _hits, u_int64_t _threshold,
                             bool _is_attacker)
    : HostAlert(c, h, cli_pctg) {
  hits = _hits;
  hits_threshold = _threshold;
  is_attacker = _is_attacker;
};

/* ***************************************************** */

ndpi_serializer* FlowHitsAlert::getAlertJSON(ndpi_serializer* serializer) {
  if (serializer == NULL) return NULL;

  ndpi_serialize_string_boolean(serializer, "is_attacker", is_attacker);
  ndpi_serialize_string_uint64(serializer, "value", hits);
  ndpi_serialize_string_uint64(serializer, "threshold", hits_threshold);

  return serializer;
}

/* ***************************************************** */
